==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/AbLaK.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QAction>
#include <QMenu>
#include <QMouseEvent>
#include <QSpinBox>
#include<QCoreApplication>

#include "Iztpr.h"
#include "Prmza.h"
#include "Jelzpn.h"
#include "AbLaK.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
aszkl::aszkl(QWidget *felvnl,jelzpn *megkap) : QTableWidget(0,0,felvnl)
<%
	kidlgz=megkap;
	akdaly=0;

	nybnvn=new QAction(ts_329,this);
	nybnvn->setStatusTip(ts_330);
        connect(nybnvn,SIGNAL(triggered()),this,SLOT(hzzqjt()));
	insertAction(0,nybnvn);

	fnqll=new QAction(ts_331,this);
	fnqll->setStatusTip(ts_332);
        connect(fnqll,SIGNAL(triggered()),this,SLOT(eler()));
	insertAction(0,fnqll);

	vnl=new QAction(ts_333,this);
	vnl->setStatusTip(ts_334);
        connect(vnl,SIGNAL(triggered()),this,SLOT(lnmtat()));
	insertAction(0,vnl);

	kket=new QAction(ts_335,this);
	kket->setStatusTip(ts_336);
        connect(kket,SIGNAL(triggered()),this,SLOT(fldlgz()));
	insertAction(0,kket);

	QAction *bprl=new QAction(ts_337,this);
	bprl->setStatusTip(ts_338);
        connect(bprl,SIGNAL(triggered()),this,SLOT(prmz()));
	insertAction(0,bprl);

        QPalette adelk=palette();
        adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
        adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
	setPalette(adelk);

	connect(this,SIGNAL(cellChanged(int,int)),this,SLOT(mrtdt(int,int)));
%>

void aszkl::kelt(const zagv& tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				setEnabled(jlzpnt > 0);

				if(jlzpnt > 0)
				<%
					akdaly=1;
					prmza *eljar=kidlgz->kket.value(jlzpnt);

					setRowCount(eljar->mgmozt);
					setColumnCount(eljar->jvsltz);

					foreach(jlszt klsirz,eljar->jlnrdz)
					<%
						QTableWidgetItem *prl=new QTableWidgetItem();
						prl->setText(klsirz.mgzerz);
						setItem(klsirz.mrtdt,klsirz.jlzpnt,prl);
					%>
					akdaly=0;
				%>
				else
				<%
					setRowCount(0);
					setColumnCount(0);
				%>
			%>
			break;
		default:
			break;
	%>
%>

void aszkl::mousePressEvent(QMouseEvent *mgmnkl)
<%
	if(mgmnkl->button()==Qt::RightButton)
	<%
		bool adelk=currentRow()>=0 and currentColumn()>=0;
		kket->setEnabled(adelk);
		vnl->setEnabled(adelk);

		QMenu::exec(actions(),mgmnkl->globalPos());
	%>
	else
	<%
		QTableWidget::mousePressEvent(mgmnkl);
	%>
%>

void aszkl::mrtdt(int kitzjl,int irnyjl)
<%
	if(akdaly) return;

	QString cel;
	QTableWidgetItem *prl=item(kitzjl,irnyjl);
	if(prl) cel=prl->text();
	else cel="";

	prmza *eljar=kidlgz->kket.value(jlzpnt);
	for(QList<jlszt>::iterator adelk=eljar->jlnrdz.begin(); adelk!=eljar->jlnrdz.end(); ++adelk)
	<%
		jlszt& klsirz=*adelk;
		if(klsirz.mrtdt==kitzjl and klsirz.jlzpnt==irnyjl)
		<%
			klsirz.mgzerz=cel;
			return;
		%>
	%>
	jlszt klsirz;
	klsirz.mrtdt=kitzjl;
	klsirz.jlzpnt=irnyjl;
	klsirz.mgzerz=cel;
	eljar->jlnrdz.push_back(klsirz);
%>

void aszkl::hzzqjt()
<%
	insertRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::eler()
<%
	insertColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->jvsltz=columnCount();
%>

void aszkl::lnmtat()
<%
	removeRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::fldlgz()
<%
	removeColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->jvsltz=columnCount();
%>

void aszkl::prmz()
<%
	asdl meghat(this);
	meghat.jlzpnt->setValue(rowCount());
	meghat.adelk->setValue(columnCount());
	if(meghat.exec()==QDialog::Accepted)
	<%
		setRowCount(meghat.jlzpnt->value());
		setColumnCount(meghat.adelk->value());

		if(jlzpnt>0)
		<%
			prmza *eljar=kidlgz->kket.value(jlzpnt);
			eljar->mgmozt=rowCount();
			eljar->jvsltz=columnCount();

			for(int i=0; i<eljar->jlnrdz.size(); ++i)
			<%
				jlszt klsirz=eljar->jlnrdz.at(i);
				if(klsirz.mrtdt >= rowCount() and klsirz.jlzpnt >= columnCount())
				<%
					eljar->jlnrdz.removeAt(i);
					i--;
				%>
			%>
		%>
	%>
%>

#include "AbLaK.moc"

==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/AbLaK.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QAction>
#include <QMenu>
#include <QMouseEvent>
#include <QSpinBox>
#include<QCoreApplication>

#include "Iztpr.h"
#include "Prmza.h"
#include "Jelzpn.h"
#include "AbLaK.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
aszkl::aszkl(QWidget *felvnl,jelzpn *megkap) : QTableWidget(0,0,felvnl)
<%
	kidlgz=megkap;
	akdaly=0;

	nybnvn=new QAction(ts_329,this);
	nybnvn->setStatusTip(ts_330);
        connect(nybnvn,SIGNAL(triggered()),this,SLOT(hzzqjt()));
	insertAction(0,nybnvn);

	fnqll=new QAction(ts_331,this);
	fnqll->setStatusTip(ts_332);
        connect(fnqll,SIGNAL(triggered()),this,SLOT(eler()));
	insertAction(0,fnqll);

	vnl=new QAction(ts_333,this);
	vnl->setStatusTip(ts_334);
        connect(vnl,SIGNAL(triggered()),this,SLOT(lnmtat()));
	insertAction(0,vnl);

	kket=new QAction(ts_335,this);
	kket->setStatusTip(ts_336);
        connect(kket,SIGNAL(triggered()),this,SLOT(fldlgz()));
	insertAction(0,kket);

	QAction *bprl=new QAction(ts_337,this);
	bprl->setStatusTip(ts_338);
        connect(bprl,SIGNAL(triggered()),this,SLOT(prmz()));
	insertAction(0,bprl);

        QPalette adelk=palette();
        adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
        adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
	setPalette(adelk);

	connect(this,SIGNAL(cellChanged(int,int)),this,SLOT(mrtdt(int,int)));
%>

void aszkl::kelt(const zagv& tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				setEnabled(jlzpnt > 0);

				if(jlzpnt > 0)
				<%
					akdaly=1;
					prmza *eljar=kidlgz->kket.value(jlzpnt);

					setRowCount(eljar->mgmozt);
					setColumnCount(eljar->lep);

					foreach(jlszt klsirz,eljar->jvsltz)
					<%
						QTableWidgetItem *prl=new QTableWidgetItem();
						prl->setText(klsirz.rabir);
						setItem(klsirz.mrtdt,klsirz.jlzpnt,prl);
					%>
					akdaly=0;
				%>
				else
				<%
					setRowCount(0);
					setColumnCount(0);
				%>
			%>
			break;
		default:
			break;
	%>
%>

void aszkl::mousePressEvent(QMouseEvent *mgmnkl)
<%
	if(mgmnkl->button()==Qt::RightButton)
	<%
		bool adelk=currentRow()>=0 and currentColumn()>=0;
		kket->setEnabled(adelk);
		vnl->setEnabled(adelk);

		QMenu::exec(actions(),mgmnkl->globalPos());
	%>
	else
	<%
		QTableWidget::mousePressEvent(mgmnkl);
	%>
%>

void aszkl::mrtdt(int kitzjl,int irnyjl)
<%
	if(akdaly) return;

	QString cel;
	QTableWidgetItem *prl=item(kitzjl,irnyjl);
	if(prl) cel=prl->text();
	else cel="";

	prmza *eljar=kidlgz->kket.value(jlzpnt);
	for(QList<jlszt>::iterator adelk=eljar->jvsltz.begin(); adelk!=eljar->jvsltz.end(); ++adelk)
	<%
		jlszt& klsirz=*adelk;
		if(klsirz.mrtdt==kitzjl and klsirz.jlzpnt==irnyjl)
		<%
			klsirz.rabir=cel;
			return;
		%>
	%>
	jlszt klsirz;
	klsirz.mrtdt=kitzjl;
	klsirz.jlzpnt=irnyjl;
	klsirz.rabir=cel;
	eljar->jvsltz.push_back(klsirz);
%>

void aszkl::hzzqjt()
<%
	insertRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::eler()
<%
	insertColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->lep=columnCount();
%>

void aszkl::lnmtat()
<%
	removeRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::fldlgz()
<%
	removeColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->lep=columnCount();
%>

void aszkl::prmz()
<%
	asdl meghat(this);
	meghat.jlzpnt->setValue(rowCount());
	meghat.adelk->setValue(columnCount());
	if(meghat.exec()==QDialog::Accepted)
	<%
		setRowCount(meghat.jlzpnt->value());
		setColumnCount(meghat.adelk->value());

		if(jlzpnt>0)
		<%
			prmza *eljar=kidlgz->kket.value(jlzpnt);
			eljar->mgmozt=rowCount();
			eljar->lep=columnCount();

			for(int i=0; i<eljar->jvsltz.size(); ++i)
			<%
				jlszt klsirz=eljar->jvsltz.at(i);
				if(klsirz.mrtdt >= rowCount() and klsirz.jlzpnt >= columnCount())
				<%
					eljar->jvsltz.removeAt(i);
					i--;
				%>
			%>
		%>
	%>
%>

#include "AbLaK.moc"
